Learn R Programming

LowWAFOMNX (version 1.1.1)

lowWAFOMNX.dimMinMax: get minimum and maximum dimension number of Low WAFOM Niederreiter-Xing Sequence

Description

get minimum and maximum dimension number of Low WAFOM Niederreiter-Xing Sequence

Usage

lowWAFOMNX.dimMinMax()

Arguments

Value

supported minimum and maximum dimension number.